class AuthTypeError(Exception):
    """AuthTypeError."""

    pass


class AuthInfoError(Exception):
    """AuthInfoError."""

    pass


class StatusCodeUnvalid(Exception):
    """StatusCodeUnvalid."""

    pass


class ResponseError(Exception):
    """ResponseError."""

    pass
